==> igniteui-angular-excel-14.2.0.tgz: package/esm5/lib/MultipleCellRKInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { MultipleCellValueInfo } from "./MultipleCellValueInfo";
import { markType } from "igniteui-angular-core";
import { ExcelUtils } from "./ExcelUtils";
import { CultureInfo } from "igniteui-angular-core";
import { Convert } from "igniteui-angular-core";
/**
 * @hidden
 */
var MultipleCellRKInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MultipleCellRKInfo, _super);
    function MultipleCellRKInfo(a, b, c, d, e) {
        return _super.call(this, a, b, c, d, e) || this;
    }
    MultipleCellRKInfo.o = function (a) {
        var b;
        var c;
        var d;
        if (((function () { var e = MultipleCellValueInfo.f(a, MultipleCellRKInfo.p, b, c, d); b = e.p2; c = e.p3; d = e.p4; return e.ret; })()) == false) {
            return null;
        }
        var e = a._r;
        return new MultipleCellRKInfo(e.b, e.a, b, c, d);
    };
    MultipleCellRKInfo.q = function (a, b, c, d) {
        d = null;
        var e = a._a5(b, c);
        if (ExcelUtils.a9(e) == false) {
            return {
                ret: false,
                p3: d
            };
        }
        var f = Convert.toDouble4(e, CultureInfo.invariantCulture);
        var g;
        if (((function () { var h = ExcelUtils.by(f, g); g = h.p1; return h.ret; })()) == false) {
            return {
                ret: false,
                p3: d
            };
        }
        d = g;
        return {
            ret: true,
            p3: d
        };
    };
    MultipleCellRKInfo.$t = markType(MultipleCellRKInfo, 'MultipleCellRKInfo', MultipleCellValueInfo.$);
    MultipleCellRKInfo.p = MultipleCellRKInfo.q;
    return MultipleCellRKInfo;
}(MultipleCellValueInfo));
export { MultipleCellRKInfo };

==> igniteui-angular-excel-18.1.1.tgz: package/esm5/lib/MultipleCellRKInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { MultipleCellValueInfo } from "./MultipleCellValueInfo";
import { markType } from "igniteui-angular-core";
import { ExcelUtils } from "./ExcelUtils";
import { CultureInfo } from "igniteui-angular-core";
import { Convert } from "igniteui-angular-core";
/**
 * @hidden
 */
var MultipleCellRKInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MultipleCellRKInfo, _super);
    function MultipleCellRKInfo(a, b, c, d, e) {
        return _super.call(this, a, b, c, d, e) || this;
    }
    MultipleCellRKInfo.o = function (a) {
        var b;
        var c;
        var d;
        if (((function () { var e = MultipleCellValueInfo.f(a, MultipleCellRKInfo.p, b, c, d); b = e.p2; c = e.p3; d = e.p4; return e.ret; })()) == false) {
            return null;
        }
        var e = a._r;
        return new MultipleCellRKInfo(e.b, e.a, b, c, d);
    };
    MultipleCellRKInfo.q = function (a, b, c, d) {
        d = null;
        var e = a._a5(b, c);
        if (ExcelUtils.bb(e) == false) {
            return {
                ret: false,
                p3: d
            };
        }
        var f = Convert.toDouble4(e, CultureInfo.invariantCulture);
        var g;
        if (((function () { var h = ExcelUtils.b0(f, g); g = h.p1; return h.ret; })()) == false) {
            return {
                ret: false,
                p3: d
            };
        }
        d = g;
        return {
            ret: true,
            p3: d
        };
    };
    MultipleCellRKInfo.$t = markType(MultipleCellRKInfo, 'MultipleCellRKInfo', MultipleCellValueInfo.$);
    MultipleCellRKInfo.p = MultipleCellRKInfo.q;
    return MultipleCellRKInfo;
}(MultipleCellValueInfo));
export { MultipleCellRKInfo };
